<!--
SPDX-FileCopyrightText: 2023 The eminus developers
SPDX-License-Identifier: Apache-2.0
-->
# extras

Test functionality of extras. These tests will always require the corresponding extra to be installed.
